@@ -18,7 +18,6 @@ pub use typegen::*;
 
 #[derive(Debug)]
 pub struct Napi {
-  pub comments: Vec<String>,
   pub item: NapiItem,
 }
 
@@ -53,4 +52,5 @@ napi_ast_impl! {
  (Struct, NapiStruct),
  (Impl, NapiImpl),
  (Enum, NapiEnum),
+ (Const, NapiConst),
 }
