@@ -3,7 +3,7 @@ use quote::ToTokens;
 use syn::Pat;
 
 use super::{ty_to_ts_type, ToTypeDef, TypeDef};
-use crate::{CallbackArg, FnKind, NapiFn};
+use crate::{js_doc_from_comments, CallbackArg, FnKind, NapiFn};
 
 impl ToTypeDef for NapiFn {
   fn to_type_def(&self) -> TypeDef {
@@ -11,14 +11,23 @@ impl ToTypeDef for NapiFn {
       r#"{prefix} {name}({args}){ret}"#,
       prefix = self.gen_ts_func_prefix(),
       name = &self.js_name,
-      args = self.gen_ts_func_args(),
-      ret = self.gen_ts_func_ret(),
+      args = self
+        .ts_args_type
+        .clone()
+        .unwrap_or_else(|| self.gen_ts_func_args()),
+      ret = self
+        .ts_return_type
+        .clone()
+        .map(|t| format!(": {}", t))
+        .unwrap_or_else(|| self.gen_ts_func_ret()),
     );
 
     TypeDef {
       kind: "fn".to_owned(),
       name: self.js_name.clone(),
       def,
+      js_mod: self.js_mod.to_owned(),
+      js_doc: js_doc_from_comments(&self.comments),
     }
   }
 }
@@ -30,11 +39,18 @@ fn gen_callback_type(callback: &CallbackArg) -> String {
       .args
       .iter()
       .enumerate()
-      .map(|(i, arg)| { format!("arg{}: {}", i, ty_to_ts_type(arg, false)) })
+      .map(|(i, arg)| {
+        let (arg, is_optional) = ty_to_ts_type(arg, false);
+        if is_optional {
+          format!("arg{}?: {}", i, arg)
+        } else {
+          format!("arg{}: {}", i, arg)
+        }
+      })
       .collect::<Vec<_>>()
       .join(", "),
     ret = match &callback.ret {
-      Some(ty) => ty_to_ts_type(ty, true),
+      Some(ty) => ty_to_ts_type(ty, true).0,
       None => "void".to_owned(),
     }
   )
@@ -56,8 +72,9 @@ impl NapiFn {
             i.mutability = None;
           }
           let mut arg = path.pat.to_token_stream().to_string().to_case(Case::Camel);
-          arg.push_str(": ");
-          arg.push_str(&ty_to_ts_type(&path.ty, false));
+          let (ts_arg, is_optional) = ty_to_ts_type(&path.ty, false);
+          arg.push_str(if is_optional { "?: " } else { ": " });
+          arg.push_str(&ts_arg);
 
           Some(arg)
         }
@@ -100,9 +117,11 @@ impl NapiFn {
         .unwrap_or_else(|| "".to_owned()),
       _ => {
         let ret = if let Some(ret) = &self.ret {
-          let ts_type = ty_to_ts_type(ret, true);
+          let (ts_type, _) = ty_to_ts_type(ret, true);
           if ts_type == "undefined" {
             "void".to_owned()
+          } else if ts_type == "Self" {
+            "this".to_owned()
           } else {
             ts_type
           }
