@@ -1,8 +1,8 @@
 use std::cell::RefCell;
 use std::collections::HashMap;
 
-use super::{ToTypeDef, TypeDef};
-use crate::{ty_to_ts_type, NapiImpl, NapiStruct, NapiStructKind};
+use super::{add_alias, ToTypeDef, TypeDef};
+use crate::{js_doc_from_comments, ty_to_ts_type, NapiImpl, NapiStruct, NapiStructKind};
 
 thread_local! {
   pub(crate) static TASK_STRUCTS: RefCell<HashMap<String, String>> = Default::default();
@@ -15,6 +15,7 @@ impl ToTypeDef for NapiStruct {
       c.borrow_mut()
         .insert(self.name.to_string(), self.js_name.clone());
     });
+    add_alias(self.name.to_string(), self.js_name.to_string());
     TypeDef {
       kind: String::from(if self.kind == NapiStructKind::Object {
         "interface"
@@ -23,6 +24,8 @@ impl ToTypeDef for NapiStruct {
       }),
       name: self.js_name.to_owned(),
       def: self.gen_ts_class(),
+      js_mod: self.js_mod.to_owned(),
+      js_doc: js_doc_from_comments(&self.comments),
     }
   }
 }
@@ -32,7 +35,7 @@ impl ToTypeDef for NapiImpl {
     if let Some(output_type) = &self.task_output_type {
       TASK_STRUCTS.with(|t| {
         t.borrow_mut()
-          .insert(self.js_name.clone(), ty_to_ts_type(output_type, false));
+          .insert(self.js_name.clone(), ty_to_ts_type(output_type, false).0);
       });
     }
     TypeDef {
@@ -41,9 +44,17 @@ impl ToTypeDef for NapiImpl {
       def: self
         .items
         .iter()
-        .map(|f| f.to_type_def().def)
+        .map(|f| {
+          format!(
+            "{}{}",
+            js_doc_from_comments(&f.comments),
+            f.to_type_def().def
+          )
+        })
         .collect::<Vec<_>>()
         .join("\\n"),
+      js_mod: self.js_mod.to_owned(),
+      js_doc: "".to_string(),
     }
   }
 }
@@ -58,10 +69,16 @@ impl NapiStruct {
       .map(|f| {
         let mut field_str = String::from("");
 
+        if !f.comments.is_empty() {
+          field_str.push_str(&js_doc_from_comments(&f.comments))
+        }
+
         if !f.setter {
           field_str.push_str("readonly ")
         }
-        let arg = format!("{}: {}", &f.js_name, ty_to_ts_type(&f.ty, false));
+        let (arg, is_optional) = ty_to_ts_type(&f.ty, false);
+        let sep = if is_optional { "?" } else { "" };
+        let arg = format!("{}{}: {}", &f.js_name, sep, arg);
         if self.kind == NapiStructKind::Constructor {
           ctor_args.push(arg.clone());
         }
